==> kiertotie-2022.11.21.tar.gz: kiertotie-2022.11.21/README.md <==
# kiertotie

Detour (Finnish: kiertotie) per rsync proxy to https mirror node.

[License: MIT](https://git.sr.ht/~sthagen/kiertotie/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/kiertotie.svg?style=flat)](https://pypi.python.org/pypi/kiertotie/)
[![downloads](https://pepy.tech/badge/kiertotie/month)](https://pepy.tech/project/kiertotie)
[![wheel](https://img.shields.io/pypi/wheel/kiertotie.svg?style=flat)](https://pypi.python.org/pypi/kiertotie/)
[![supported-versions](https://img.shields.io/pypi/pyversions/kiertotie.svg?style=flat)](https://pypi.python.org/pypi/kiertotie/)
[![supported-implementations](https://img.shields.io/pypi/implementation/kiertotie.svg?style=flat)](https://pypi.python.org/pypi/kiertotie/)

## Documentation

User and developer [documentation of kiertotie](https://codes.dilettant.life/docs/kiertotie).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of kiertotie](https://todo.sr.ht/~sthagen/kiertotie).

## Primary Source repository

The primary source of `kiertotie` lives somewhere on a mountain in Central Switzerland.
But, we use decentralized version control (git), so any clone can become the source to everyone's benefit, no central only code.
Anyway, the preferred public clones of `kiertotie` are:

* [on codeberg](https://codeberg.org/sthagen/kiertotie) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/kiertotie) - a collection of tools useful for software development.

# Status

Experimental.

**Note**: The default branch is `default`.

==> kiertotie-2023.1.5.tar.gz: kiertotie-2023.1.5/README.md <==
# Kiertotie

Detour (Finnish: kiertotie) per rsync proxy to https mirror node.

[License: MIT](https://git.sr.ht/~sthagen/kiertotie/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](third-party/README.md).

[![version](https://img.shields.io/pypi/v/kiertotie.svg?style=flat)](https://pypi.python.org/pypi/kiertotie/)
[![downloads](https://pepy.tech/badge/kiertotie/month)](https://pepy.tech/project/kiertotie)
[![wheel](https://img.shields.io/pypi/wheel/kiertotie.svg?style=flat)](https://pypi.python.org/pypi/kiertotie/)
[![supported-versions](https://img.shields.io/pypi/pyversions/kiertotie.svg?style=flat)](https://pypi.python.org/pypi/kiertotie/)
[![supported-implementations](https://img.shields.io/pypi/implementation/kiertotie.svg?style=flat)](https://pypi.python.org/pypi/kiertotie/)

## Documentation

User and developer [documentation of kiertotie](https://codes.dilettant.life/docs/kiertotie).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of kiertotie](https://todo.sr.ht/~sthagen/kiertotie).

## Primary Source repository

The main source of `kiertotie` is on a mountain in central Switzerland.
We use distributed version control (git). No central hub. Each clone can become a new source for the benefit of all.
The preferred public clones of `kiertotie` are:

* [on codeberg](https://codeberg.org/sthagen/kiertotie) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/kiertotie) - a collection of tools useful for software development.

# Status

Experimental.

**Note**: The default branch is `default`.
